@@ -31,9 +31,17 @@ sub from_arguments_to_choices {
         if ( $webpage_url =~ /^p#(?:[FP]L)?([\p{PerlWord}-]+)\z/ ) {
             $webpage_url = sprintf 'https://www.youtube.com/playlist?list=%s/', $1;
         }
-        if ( my $uploader_id = _youtube_user_id( $opt, $webpage_url ) ) {
+        if ( my $user_id = _youtube_user_id( $opt, $webpage_url ) ) {
             my $ex = 'youtube';
-            my $tmp = _youtube_list_info( $opt, 'CL', $uploader_id );
+            my $tmp = _youtube_list_info( $opt, 'User', $user_id );
+            next if ! defined $tmp;
+            my ( $vi ) = keys %{$tmp->{$ex}};
+            my $prompt = $tmp->{$ex}{$vi}{uploader};
+            choose_videos( $opt, $info, $tmp, $ex, $prompt );
+        }
+        elsif ( my $channel_id = _youtube_channel_id( $opt, $webpage_url ) ) {
+            my $ex = 'youtube';
+            my $tmp = _youtube_list_info( $opt, 'Channel', $channel_id );
             next if ! defined $tmp;
             my ( $vi ) = keys %{$tmp->{$ex}};
             my $prompt = $tmp->{$ex}{$vi}{uploader};
@@ -105,6 +113,17 @@ sub _youtube_user_id {
 }
 
 
+sub _youtube_channel_id {
+    my ( $opt, $webpage_url ) = @_;
+    my $invalid_char = $opt->{invalid_char};
+    return    if ! $opt->{fast_list_youtube};
+    return    if ! $webpage_url;
+    return    if   $webpage_url !~ $opt->{yt_regexp};
+    return $1 if   $webpage_url =~ m{/channel/([^$invalid_char]+)};
+    return;
+}
+
+
 sub _vimeo_uploader_id {
     my ( $opt, $webpage_url ) = @_;
     return    if ! $opt->{fast_list_vimeo};
@@ -118,13 +137,13 @@ sub _youtube_list_info {
     my( $opt, $type, $list_id ) = @_;
     printf "Fetching info data ... \n";
     #my $url = sprintf 'https://www.youtube.com/user/%s/videos?sort=dd&view=0&flow=list', $list_id;
-    my $url = sprintf 'https://www.youtube.com/user/%s/videos', $list_id;
+    my $url = sprintf 'https://www.youtube.com/%s/%s/videos', lc $type, $list_id;
     my $ex = 'youtube';
     my $tmp_info = {};
     my $a_ref = get_youtube_list_info( $opt, $url );
     if ( ! defined $a_ref ) {
         push @{$opt->{error_get_download_infos}}, sprintf "%s: %s", $type, $list_id;
-        my $prompt = "Error list info: $type - $url";
+        my $prompt = "Error list-info: $url";
         choose( [ 'ENTER to continue' ], { prompt => $prompt } );
         return;
     }
