@@ -49,7 +49,7 @@ sub sanitize_for_path {
     my ( $opt, $str ) = @_;
     $str =~ s/^\s+|\s+\z//g;
     $str =~ s/\s/_/g             if $opt->{replace_spaces};
-    #$str =~ s/^\.+//            if $^O eq 'Unix';
+    $str =~ s/^\.+//             if $opt->{sanitize_filename};
     $str =~ s{["/\\:*?<>&|]}{-}g if $opt->{sanitize_filename} == 1;
     $str =~ s{/}{-}g             if $opt->{sanitize_filename} == 2;
     # NTFS unsupported characters:  / \ : " * ? < > |
